@@ -1,4 +1,4 @@
-from functools import update_wrapper, partial
+from functools import update_wrapper,wraps
 from multiprocessing import Process
 from typing import List
 import copy
@@ -15,7 +15,7 @@ from function_scheduling_distributed_framework.publishers.base_publisher import
 from function_scheduling_distributed_framework.factories.publisher_factotry import get_publisher
 from function_scheduling_distributed_framework.factories.consumer_factory import get_consumer
 # noinspection PyUnresolvedReferences
-from function_scheduling_distributed_framework.utils import nb_print, patch_print, LogManager, LoggerMixin
+from function_scheduling_distributed_framework.utils import nb_print, patch_print, LogManager,get_logger, LoggerMixin
 from function_scheduling_distributed_framework.timing_job import fsdf_background_scheduler,timing_publish_deco
 
 
@@ -115,7 +115,7 @@ def task_deco(queue_name, *, function_timeout=0, threads_num=50,
         func.push = func.delay = consumer.publisher_of_same_queue.push
         func.clear = func.clear_queue = consumer.publisher_of_same_queue.clear
 
-        # @functools.wraps(func)
+        # @wraps(func)
         def __deco(*args, **kwargs):
             return func(*args, **kwargs)
 
